# Generated by Django 5.0.7 on 2024-08-07 09:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0055_alter_agent_style_icon"),
    ]

    operations = [
        migrations.AddField(
            model_name="searchmodelconfig",
            name="cross_encoder_model_config",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
